## 1.1.8

Maintenance:

  - Up version python-slugify

## 1.1.7

Enhancement:
  - Fix: False alarm on model/instance check. (@titusz)

## 1.1.6

Maintenance:

  - Up version python-slugify, fixed broken status links on github

## 1.1.5

Enhancement:

  - Ability to remove `stopwords` from string
  - Ability to auto truncate string to match model field's max_length

## 1.0.5

Fix:

  - PyPI Cleanup

## 1.0.4

Enhancement:

  - Added option to save word order
  - Added more tests
  - Added Django 1.8 and dropped unsupported Django

## 1.0.3

Enhancement:

  - Support pypy
  - Support Django 1.7
  - More test cases
  - Update slugify

## 1.0.2

Enhancement:

  - PEP8 Compliant

## 1.0.1

Enhancement:

  - Added support for Django 1.6.1
  - Added support for Python 3.x

Misc:
  - Dropped support for Django<=1.4.10
  - Dropped support for Python 2.6


## 1.0.0

Enhancement:

  - Support Django>=1.6


## 0.2.0

Features:

  - Added an option to choose a non-dash separator


## 0.1.0

Features:

  - Added the ability to truncate slugs


## 0.0.9

Enhancement:

  -- Removed buildout dependency
  -- Move Unicode Slug functionality into its own python-slugify module


## 0.0.1

Features:

  - Initial Release
